==> haruka-bot-1.5.3.post2.tar.gz: haruka-bot-1.5.3.post2/README.md <==
[![HarukaBot](https://socialify.git.ci/SK-415/HarukaBot/image?description=1&font=Source%20Code%20Pro&forks=1&issues=1&language=1&logo=https%3A%2F%2Fraw.githubusercontent.com%2FSK-415%2FHarukaBot%2Fmaster%2Fdocs%2F.vuepress%2Fpublic%2Flogo.png&owner=1&pattern=Charlie%20Brown&stargazers=1&theme=Dark)](https://haruka-bot.sk415.icu/)

# [HarukaBot](https://haruka-bot.sk415.icu)——优雅的 B 站推送 QQ 机器人

名称来源：[@白神遥Haruka](https://space.bilibili.com/477332594)

Logo 画师：[@Ratto](https://space.bilibili.com/23242907)

[![VERSION](https://img.shields.io/pypi/v/haruka-bot)](https://haruka-bot.sk415.icu/about/CHANGELOG.html)
[![qq group](https://img.shields.io/badge/QQ%E7%BE%A4-629574472-orange)](https://jq.qq.com/?_wv=1027&k=sHPbCRAd)
[![time tracker](https://wakatime.com/badge/github/SK-415/HarukaBot.svg)](https://wakatime.com/badge/github/SK-415/HarukaBot)

## 简介

一款将哔哩哔哩 UP 主的直播与动态信息推送至 QQ 的机器人。基于 [NoneBot2](https://github.com/nonebot/nonebot2) 开发，前身为 [dd-bot](https://github.com/SK-415/dd-bot) 。

## 特色功能

HarukaBot 针对不同的推送场景（粉丝群、娱乐群、直播通知群），提供了个性化设置：

- 自定义推送内容，每位 UP 主可限制仅动态、仅直播。
- 群内开启权限限制，仅管理员以上可以使用机器人。
- 指定推送内容@全体成员，次数用光自动忽略。
- 同时连接多个 QQ 号，避免@全体成员次数不够。

## [文档（点击查看）](https://haruka-bot.sk415.icu)

## 部分功能展示

![demo](/docs/.vuepress/public/demo.png)

## 特别感谢

- [@mnixry](https://github.com/mnixry)：感谢混淆佬为本项目提供的**技♂术指导**。
- [@wosiwq](https://github.com/wosiwq)：感谢 W 桑撰写的「小小白白话文」。
- [NoneBot2](https://github.com/nonebot/nonebot2)：HarukaBot 使用的开发框架。
- [go-cqhttp](https://github.com/Mrs4s/go-cqhttp)：稳定完善的 CQHTTP 实现。
- [bilibili-API-collect](https://github.com/SocialSisterYi/bilibili-API-collect)：非常详细的 B 站 API 文档。
- [bilibili_api](https://github.com/Passkou/bilibili_api)：Python 实现的 B 站 API 库。
- [HarukaBot_Guild_Patch](https://github.com/17TheWord/HarukaBot_Guild_Patch) 可以让HarukaBot适用于频道的补丁。（已合入 HarukaBot）

## 支持与贡献

觉得好用可以给这个项目点个 Star 或者去 [爱发电](https://afdian.net/@HarukaBot) 投喂我。

有意见或者建议也欢迎提交 [Issues](https://github.com/SK-415/HarukaBot/issues) 和 [Pull requests](https://github.com/SK-415/HarukaBot/pulls)。

## 许可证
本项目使用 [GNU AGPLv3](https://choosealicense.com/licenses/agpl-3.0/) 作为开源许可证。

==> haruka-bot-1.6.0.post2.tar.gz: haruka-bot-1.6.0.post2/README.md <==
[![HarukaBot](https://socialify.git.ci/SK-415/HarukaBot/image?description=1&font=Source%20Code%20Pro&forks=1&issues=1&language=1&logo=https%3A%2F%2Fraw.githubusercontent.com%2FSK-415%2FHarukaBot%2Fmaster%2Fdocs%2F.vuepress%2Fpublic%2Flogo.png&owner=1&pattern=Charlie%20Brown&stargazers=1&theme=Dark)](https://haruka-bot.sk415.icu/)

# [HarukaBot](https://haruka-bot.sk415.icu)——优雅的 B 站推送 QQ 机器人

名称来源：[@白神遥Haruka](https://space.bilibili.com/477332594)

Logo 画师：[@Ratto](https://space.bilibili.com/23242907)

[![VERSION](https://img.shields.io/pypi/v/haruka-bot)](https://haruka-bot.sk415.icu/about/CHANGELOG.html)
[![qq group](https://img.shields.io/badge/QQ%E7%BE%A4-629574472-orange)](https://jq.qq.com/?_wv=1027&k=sHPbCRAd)
[![time tracker](https://wakatime.com/badge/github/SK-415/HarukaBot.svg)](https://wakatime.com/badge/github/SK-415/HarukaBot)

## 简介

一款将哔哩哔哩 UP 主的直播与动态信息推送至 QQ 的机器人。基于 [NoneBot2](https://github.com/nonebot/nonebot2) 开发，前身为 [dd-bot](https://github.com/SK-415/dd-bot) 。

## 特色功能

HarukaBot 针对不同的推送场景（粉丝群、娱乐群、直播通知群），提供了个性化设置：

- 自定义推送内容，每位 UP 主可限制仅动态、仅直播。
- 群内开启权限限制，仅管理员以上可以使用机器人。
- 指定推送内容@全体成员，次数用光自动忽略。
- 同时连接多个 QQ 号，避免@全体成员次数不够。

## [文档（点击查看）](https://haruka-bot.sk415.icu)

## 部分功能展示

![demo](/docs/.vuepress/public/demo.png)

## 特别感谢

- [@mnixry](https://github.com/mnixry)：感谢混淆佬为本项目提供的**技♂术指导**。
- [@wosiwq](https://github.com/wosiwq)：感谢 W 桑撰写的「小小白白话文」。
- [NoneBot2](https://github.com/nonebot/nonebot2)：HarukaBot 使用的开发框架。
- [go-cqhttp](https://github.com/Mrs4s/go-cqhttp)：稳定完善的 CQHTTP 实现。
- [bilibili-API-collect](https://github.com/SocialSisterYi/bilibili-API-collect)：非常详细的 B 站 API 文档。
- [bilibili_api](https://github.com/Passkou/bilibili_api)：Python 实现的 B 站 API 库。
- [HarukaBot_Guild_Patch](https://github.com/17TheWord/HarukaBot_Guild_Patch)：可以让HarukaBot适用于频道的补丁。（已合入 HarukaBot）

## 支持与贡献

觉得好用可以给这个项目点个 Star 或者去 [爱发电](https://afdian.net/@HarukaBot) 投喂我。

有意见或者建议也欢迎提交 [Issues](https://github.com/SK-415/HarukaBot/issues) 和 [Pull requests](https://github.com/SK-415/HarukaBot/pulls)。

## 许可证
本项目使用 [GNU AGPLv3](https://choosealicense.com/licenses/agpl-3.0/) 作为开源许可证。
